@@ -33,7 +33,7 @@ from ..Exceptions import MetadataAlreadyFixedByFile
 from ..HeightContainer import UniformTopographyInterface
 from ..NonuniformLineScan import NonuniformLineScan
 from ..UniformLineScanAndTopography import Topography, UniformLineScan
-from ..UnitConversion import length_units, mangle_length_unit_utf8
+from ..Support.UnitConversion import length_units, mangle_length_unit_utf8
 from .common import CHANNEL_NAME_INFO_KEY, text
 from .FromFile import make_wrapped_reader
 
@@ -243,7 +243,6 @@ def read_asc(fobj, physical_sizes=None, height_scale_factor=None, x_factor=1.0,
                 zfac = length_units[zunit] / length_units[unit]
             else:
                 zfac *= length_units[zunit] / length_units[unit]
-        info['unit'] = unit
 
     # handle channel name
     # we use the info dict here to transfer the channel name
@@ -298,7 +297,7 @@ When writing your own ASCII files, we recommend to prepent the header with a
 
 
 @text
-def read_xyz(fobj, physical_sizes=None, height_scale_factor=None, unit=None, info={}, periodic=False, tol=1e-6):
+def read_xyz(fobj, physical_sizes=None, height_scale_factor=None, unit=None, info={}, periodic=None, tol=1e-6):
     """
     Load xyz-file. These files contain line scan information in terms of
     (x,y)-positions.
@@ -329,9 +328,12 @@ def read_xyz(fobj, physical_sizes=None, height_scale_factor=None, unit=None, inf
                 physical_sizes = d_uniform * len(x)
             else:
                 raise MetadataAlreadyFixedByFile('physical_sizes')
-            t = UniformLineScan(z, physical_sizes, unit=unit, info=info, periodic=periodic)
+            t = UniformLineScan(z, physical_sizes,
+                                periodic=False if periodic is None else periodic,
+                                unit=unit,
+                                info=info)
         else:
-            if periodic:
+            if periodic is not None and periodic:
                 raise ValueError('XYZ reader found nonuniform data, and the user specified that it is periodic. '
                                  'Nonuniform line scans cannot be periodic.')
             t = NonuniformLineScan(x, z, unit=unit, info=info)
