@@ -39,11 +39,13 @@ from .DI import DIReader
 from .H5 import H5Reader
 from .IBW import IBWReader
 from .Matlab import MatReader
+from .Mitutoyo import MitutoyoReader
 from .MI import MIReader
 from .NC import NCReader
 from .NPY import NPYReader
 from .OPD import OPDReader
 from .OPDx import OPDxReader
+from .VK4 import VK4Reader
 from .ZON import ZONReader
 
 # Only writers
@@ -62,10 +64,12 @@ readers = [
     X3PReader,
     IBWReader,
     MIReader,
+    MitutoyoReader,
     NCReader,
     # NCReader must come before H5Reader, because NC4 *is* a specialized form of HDF5
     H5Reader,
     NPYReader,
+    VK4Reader,
     ZONReader,
     HGTReader,
 ]
